@@ -35,7 +35,7 @@ from airflow.api_fastapi.auth.managers.models.resource_details import (
     VariableDetails,
 )
 from airflow.api_fastapi.common.types import MenuItem
-from airflow.exceptions import AirflowException
+from airflow.providers.common.compat.sdk import AirflowException
 from airflow.providers.keycloak.auth_manager.constants import (
     CONF_CLIENT_ID_KEY,
     CONF_REALM_KEY,
@@ -208,10 +208,8 @@ class TestKeycloakAuthManager:
             [403, False],
         ],
     )
-    @patch("airflow.providers.keycloak.auth_manager.keycloak_auth_manager.requests")
     def test_is_authorized(
         self,
-        mock_requests,
         function,
         method,
         details,
@@ -222,14 +220,18 @@ class TestKeycloakAuthManager:
         auth_manager,
         user,
     ):
-        mock_requests.post.return_value.status_code = status_code
+        mock_response = Mock()
+        mock_response.status_code = status_code
+        auth_manager.http_session.post = Mock(return_value=mock_response)
 
         result = getattr(auth_manager, function)(method=method, user=user, details=details)
 
         token_url = auth_manager._get_token_url("server_url", "realm")
         payload = auth_manager._get_payload("client_id", permission, attributes)
         headers = auth_manager._get_headers("access_token")
-        mock_requests.post.assert_called_once_with(token_url, data=payload, headers=headers)
+        auth_manager.http_session.post.assert_called_once_with(
+            token_url, data=payload, headers=headers, timeout=5
+        )
         assert result == expected
 
     @pytest.mark.parametrize(
@@ -245,11 +247,10 @@ class TestKeycloakAuthManager:
             "is_authorized_pool",
         ],
     )
-    @patch("airflow.providers.keycloak.auth_manager.keycloak_auth_manager.requests")
-    def test_is_authorized_failure(self, mock_requests, function, auth_manager, user):
+    def test_is_authorized_failure(self, function, auth_manager, user):
         resp = Mock()
         resp.status_code = 500
-        mock_requests.post.return_value = resp
+        auth_manager.http_session.post = Mock(return_value=resp)
 
         with pytest.raises(AirflowException) as e:
             getattr(auth_manager, function)(method="GET", user=user)
@@ -269,12 +270,11 @@ class TestKeycloakAuthManager:
             "is_authorized_pool",
         ],
     )
-    @patch("airflow.providers.keycloak.auth_manager.keycloak_auth_manager.requests")
-    def test_is_authorized_invalid_request(self, mock_requests, function, auth_manager, user):
+    def test_is_authorized_invalid_request(self, function, auth_manager, user):
         resp = Mock()
         resp.status_code = 400
         resp.text = json.dumps({"error": "invalid_scope", "error_description": "Invalid scopes: GET"})
-        mock_requests.post.return_value = resp
+        auth_manager.http_session.post = Mock(return_value=resp)
 
         with pytest.raises(AirflowException) as e:
             getattr(auth_manager, function)(method="GET", user=user)
@@ -321,10 +321,8 @@ class TestKeycloakAuthManager:
             [403, False],
         ],
     )
-    @patch("airflow.providers.keycloak.auth_manager.keycloak_auth_manager.requests")
     def test_is_authorized_dag(
         self,
-        mock_requests,
         method,
         access_entity,
         details,
@@ -335,7 +333,9 @@ class TestKeycloakAuthManager:
         auth_manager,
         user,
     ):
-        mock_requests.post.return_value.status_code = status_code
+        mock_response = Mock()
+        mock_response.status_code = status_code
+        auth_manager.http_session.post = Mock(return_value=mock_response)
 
         result = auth_manager.is_authorized_dag(
             method=method, user=user, access_entity=access_entity, details=details
@@ -344,7 +344,9 @@ class TestKeycloakAuthManager:
         token_url = auth_manager._get_token_url("server_url", "realm")
         payload = auth_manager._get_payload("client_id", permission, attributes)
         headers = auth_manager._get_headers("access_token")
-        mock_requests.post.assert_called_once_with(token_url, data=payload, headers=headers)
+        auth_manager.http_session.post.assert_called_once_with(
+            token_url, data=payload, headers=headers, timeout=5
+        )
         assert result == expected
 
     @pytest.mark.parametrize(
@@ -354,16 +356,16 @@ class TestKeycloakAuthManager:
             [403, False],
         ],
     )
-    @patch("airflow.providers.keycloak.auth_manager.keycloak_auth_manager.requests")
     def test_is_authorized_view(
         self,
-        mock_requests,
         status_code,
         expected,
         auth_manager,
         user,
     ):
-        mock_requests.post.return_value.status_code = status_code
+        mock_response = Mock()
+        mock_response.status_code = status_code
+        auth_manager.http_session.post = Mock(return_value=mock_response)
 
         result = auth_manager.is_authorized_view(access_view=AccessView.CLUSTER_ACTIVITY, user=user)
 
@@ -372,7 +374,9 @@ class TestKeycloakAuthManager:
             "client_id", "View#GET", {RESOURCE_ID_ATTRIBUTE_NAME: "CLUSTER_ACTIVITY"}
         )
         headers = auth_manager._get_headers("access_token")
-        mock_requests.post.assert_called_once_with(token_url, data=payload, headers=headers)
+        auth_manager.http_session.post.assert_called_once_with(
+            token_url, data=payload, headers=headers, timeout=5
+        )
         assert result == expected
 
     @pytest.mark.parametrize(
@@ -382,23 +386,25 @@ class TestKeycloakAuthManager:
             [403, False],
         ],
     )
-    @patch("airflow.providers.keycloak.auth_manager.keycloak_auth_manager.requests")
     def test_is_authorized_custom_view(
         self,
-        mock_requests,
         status_code,
         expected,
         auth_manager,
         user,
     ):
-        mock_requests.post.return_value.status_code = status_code
+        mock_response = Mock()
+        mock_response.status_code = status_code
+        auth_manager.http_session.post = Mock(return_value=mock_response)
 
         result = auth_manager.is_authorized_custom_view(method="GET", resource_name="test", user=user)
 
         token_url = auth_manager._get_token_url("server_url", "realm")
         payload = auth_manager._get_payload("client_id", "Custom#GET", {RESOURCE_ID_ATTRIBUTE_NAME: "test"})
         headers = auth_manager._get_headers("access_token")
-        mock_requests.post.assert_called_once_with(token_url, data=payload, headers=headers)
+        auth_manager.http_session.post.assert_called_once_with(
+            token_url, data=payload, headers=headers, timeout=5
+        )
         assert result == expected
 
     @pytest.mark.parametrize(
@@ -414,12 +420,11 @@ class TestKeycloakAuthManager:
             [403, [{"scopes": ["MENU"], "rsname": "Assets"}], set()],
         ],
     )
-    @patch("airflow.providers.keycloak.auth_manager.keycloak_auth_manager.requests")
-    def test_filter_authorized_menu_items(
-        self, mock_requests, status_code, response, expected, auth_manager, user
-    ):
-        mock_requests.post.return_value.status_code = status_code
-        mock_requests.post.return_value.json.return_value = response
+    def test_filter_authorized_menu_items(self, status_code, response, expected, auth_manager, user):
+        mock_response = Mock()
+        mock_response.status_code = status_code
+        mock_response.json.return_value = response
+        auth_manager.http_session.post = Mock(return_value=mock_response)
         menu_items = [MenuItem.ASSETS, MenuItem.CONNECTIONS]
 
         result = auth_manager.filter_authorized_menu_items(menu_items, user=user)
@@ -429,19 +434,20 @@ class TestKeycloakAuthManager:
             "client_id", [("MENU", MenuItem.ASSETS.value), ("MENU", MenuItem.CONNECTIONS.value)]
         )
         headers = auth_manager._get_headers("access_token")
-        mock_requests.post.assert_called_once_with(token_url, data=payload, headers=headers)
+        auth_manager.http_session.post.assert_called_once_with(
+            token_url, data=payload, headers=headers, timeout=5
+        )
         assert set(result) == expected
 
     @pytest.mark.parametrize(
         "status_code",
         [400, 500],
     )
-    @patch("airflow.providers.keycloak.auth_manager.keycloak_auth_manager.requests")
-    def test_filter_authorized_menu_items_with_failure(self, mock_requests, status_code, auth_manager, user):
+    def test_filter_authorized_menu_items_with_failure(self, status_code, auth_manager, user):
         resp = Mock()
         resp.status_code = status_code
         resp.text = json.dumps({})
-        mock_requests.post.return_value = resp
+        auth_manager.http_session.post = Mock(return_value=resp)
 
         menu_items = [MenuItem.ASSETS, MenuItem.CONNECTIONS]
 
@@ -453,7 +459,9 @@ class TestKeycloakAuthManager:
             "client_id", [("MENU", MenuItem.ASSETS.value), ("MENU", MenuItem.CONNECTIONS.value)]
         )
         headers = auth_manager._get_headers("access_token")
-        mock_requests.post.assert_called_once_with(token_url, data=payload, headers=headers)
+        auth_manager.http_session.post.assert_called_once_with(
+            token_url, data=payload, headers=headers, timeout=5
+        )
 
     def test_get_cli_commands_return_cli_commands(self, auth_manager):
         assert len(auth_manager.get_cli_commands()) == 1
